@@ -29,10 +29,8 @@
 #include "platform.h"
 #include "util.h"
 
-#ifndef	PJL_NO_NAMESPACES
 using namespace PJL;
 using namespace std;
-#endif
 
 extern char const*	me;
 
