@@ -27,7 +27,6 @@
 #include <set>
 
 // local
-#include "fake_ansi.h"			/* for iterator, std */
 #include "iso8859-1.h"
 #include "util.h"			/* for to_lower() */
 
@@ -103,7 +102,8 @@ protected:
 	class encoded_char_range::const_iterator :
 		public encoded_char_range,
 		public std::iterator<
-			std::forward_iterator_tag, value_type const
+			std::forward_iterator_tag,
+			encoded_char_range::value_type const
 		>
 //
 // DESCRIPTION
@@ -176,6 +176,8 @@ public:
 	typedef encoded_char_range::value_type value_type;
 	typedef encoded_char_range::pointer pointer;
 
+	virtual ~decoder();
+
 	static void	reset_all();
 protected:
 	decoder()	{ set_.insert( this ); }
@@ -401,8 +403,7 @@ inline ECR_CI::const_iterator( ECR const *ecr, pointer start_pos ) :
 //*****************************************************************************
 {
 	ECR_CI const temp = *this;
-	operator++();
-	return temp;
+	return ++*this, temp;
 }
 
 //*****************************************************************************
@@ -472,3 +473,4 @@ inline bool operator!=( ECR_CI::pointer p, ECR_CI const &e ) {
 #undef	ECR
 
 #endif	/* encoded_char_H */
+/* vim:set noet sw=8 ts=8: */
