@@ -47,29 +47,34 @@ enum {
 
 	// unique to search
 	Exit_Malformed_Query		= 50,
+#ifdef	FEATURE_word_pos
+	Exit_No_Word_Pos_Data		= 51,
+#endif
 #ifdef	SEARCH_DAEMON
-	Exit_No_Write_PID		= 51,
-	Exit_No_Host_or_IP		= 52,
-	Exit_No_TCP_Socket		= 53,
-	Exit_No_Unix_Socket		= 54,
-	Exit_No_Unlink			= 55,
-	Exit_No_TCP_Bind		= 56,
-	Exit_No_Unix_Bind		= 57,
-	Exit_No_TCP_Listen		= 58,
-	Exit_No_Unix_Listen		= 59,
-	Exit_No_Select			= 60,
-	Exit_No_Accept			= 61,
-	Exit_No_Fork			= 62,
-	Exit_No_Change_Dir		= 63,
-	Exit_No_Create_Thread		= 64,
-	Exit_No_Detach_Thread		= 65,
-	Exit_No_Init_Thread_Condition	= 66,
-	Exit_No_Init_Thread_Mutex	= 67,
-	Exit_No_User			= 68,
-	Exit_No_Group			= 69,
+	Exit_No_Write_PID		= 60,
+	Exit_No_Host_or_IP		= 61,
+	Exit_No_TCP_Socket		= 62,
+	Exit_No_Unix_Socket		= 63,
+	Exit_No_Unlink			= 64,
+	Exit_No_TCP_Bind		= 65,
+	Exit_No_Unix_Bind		= 66,
+	Exit_No_TCP_Listen		= 67,
+	Exit_No_Unix_Listen		= 68,
+	Exit_No_Select			= 69,
+	Exit_No_Accept			= 70,
+	Exit_No_Fork			= 71,
+	Exit_No_Change_Dir		= 72,
+	Exit_No_Create_Thread		= 73,
+	Exit_No_Create_Thread_Key	= 74,
+	Exit_No_Detach_Thread		= 75,
+	Exit_No_Init_Thread_Condition	= 76,
+	Exit_No_Init_Thread_Mutex	= 77,
+	Exit_No_User			= 78,
+	Exit_No_Group			= 79,
 #endif
 
 	Exit_End_Enum_Marker
 };
 
 #endif	/* exit_codes_H */
+/* vim:set noet sw=8 ts=8: */
