@@ -28,7 +28,6 @@
 #include <map>
 
 // local
-#include "fake_ansi.h"			/* for std */
 #include "less.h"
 
 //*****************************************************************************
@@ -85,3 +84,4 @@ private:
 #endif	/* latex_command_map_H */
 
 #endif	/* MOD_latex */
+/* vim:set noet sw=8 ts=8: */
