@@ -33,6 +33,9 @@ static option_stream::spec const opt_spec[] = {
 	"format",		1, 'F',
 	"max-results",		1, 'm',
 	"dump-meta",		0, 'M',
+#ifdef	FEATURE_word_pos
+	"near",			1, 'n',
+#endif
 	"word-percent",		1, 'p',
 	"skip-results",		1, 'r',
 	"separator",		1, 'R',
@@ -49,6 +52,9 @@ static option_stream::spec const opt_spec[] = {
 	"index-file",		1, 'i',
 #ifdef	SEARCH_DAEMON
 	"daemon-type",		1, 'b',
+#ifdef	__APPLE__
+	"launchd",		0, 'X',
+#endif
 	"no-background",	0, 'B',
 	"group",		1, 'G',
 	"pid-file",		1, 'P',
@@ -64,3 +70,4 @@ static option_stream::spec const opt_spec[] = {
 #endif	/* SEARCH_DAEMON_OPTIONS_ONLY */
 	0
 };
+/* vim:set noet sw=8 ts=8: */
