@@ -30,9 +30,7 @@
 #include "platform.h"
 #include "word_util.h"
 
-#ifndef	PJL_NO_NAMESPACES
 using namespace std;
-#endif
 
 //*****************************************************************************
 //
@@ -292,3 +290,4 @@ using namespace std;
 	c = d;
 	return true;
 }
+/* vim:set noet sw=8 ts=8: */
