@@ -29,7 +29,6 @@
 // local
 #include "config.h"
 #include "encoded_char.h"
-#include "fake_ansi.h"			/* for std */
 #include "util.h"
 
 //*****************************************************************************
@@ -169,3 +168,4 @@ extern bool	move_if_match(
 		);
 
 #endif	/* word_util_H */
+/* vim:set noet sw=8 ts=8: */
