@@ -30,9 +30,7 @@
 #include "util.h"
 #include "xml_formatter.h"
 
-#ifndef	PJL_NO_NAMESPACES
 using namespace std;
-#endif
 
 #define	SWISH_PATH	"/pauljlucas/software/swish"
 #define	SWISH_NS_URI	"http://www.pauljlucas.org" SWISH_PATH
@@ -51,7 +49,7 @@ extern index_segment directories;
 //
 // SYNOPSIS
 //
-	string escape( char const *s )
+	static string escape( char const *s )
 //
 // DESCRIPTION
 //
@@ -84,6 +82,25 @@ extern index_segment directories;
 	return result;
 }
 
+//*****************************************************************************
+//
+// SYNOPSIS
+//
+        xml_formatter::~xml_formatter()
+//
+// DESCRIPTION
+//
+//      Destroy an xml_formatter.
+//
+// NOTE
+//
+//      This is out-of-line only because it's virtual.
+//
+//*****************************************************************************
+{
+    // do nothing
+}
+
 //*****************************************************************************
 //
 // SYNOPSIS
@@ -113,15 +130,8 @@ extern index_segment directories;
 
 	if ( !stop_words.empty() ) {
 		out_ << "  <IgnoredList>\n";
-		FOR_EACH( stop_word_set, stop_words, word ) {
-			out_ <<	"    <Ignored>"
-#ifdef	PJL_GCC_295 /* see the comment in platform.h */
-			     <<	word->c_str()
-#else
-			     <<	*word
-#endif
-			     <<	"</Ignored>\n";
-		}
+		FOR_EACH( stop_word_set, stop_words, word )
+			out_ <<	"    <Ignored>" << *word << "</Ignored>\n";
 		out_ << "  </IgnoredList>\n";
 	}
 
@@ -180,3 +190,4 @@ extern index_segment directories;
 		out_ << "  </ResultList>\n";
 	out_ << "</SearchResults>\n";
 }
+/* vim:set noet sw=8 ts=8: */
