@@ -41,6 +41,7 @@
 public:
 	xml_formatter( std::ostream &o, int results ) :
 		results_formatter( o, results ) { }
+	virtual ~xml_formatter();
 
 	virtual void pre( stop_word_set const& ) const;
 	virtual void result( int rank, file_info const& ) const;
@@ -48,3 +49,4 @@ public:
 };
 
 #endif	/* xml_formatter_H */
+/* vim:set noet sw=8 ts=8: */
